@@ -12,28 +12,42 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
+import os
 from enum import Enum
 from pathlib import Path
 
 
 class settings:
     _MODEL_LIMIT_SIZE_MB = 30
-    _PROTOCOL_VERSION = [0, 0, 1]
-
-    _AVAILABLE_DEVICES=[
-        "all",
-
-        # "OnePlus6t",
-        "SonyXperiaZ5",
-        "SamsungGalaxyNote3",
-        "Nexus5X",
-    ]
+    _PROTOCOL_VERSION = [0, 0, 2]
 
     _CONFIGURE_DIR = Path.home() / ".edgebenchmark"
     _CREDENTIALS_FILE_PATH = _CONFIGURE_DIR / "credentials"
     _TOKEN_LENGTH = 128
-    _MODEL_ENDPOINT = "https://edgebenchmark.com/api/model"
-    _DEVICE_ENDPOINT = "https://edgebenchmark.com/api/devices"
+    _WEB_SERVER_URL = "https://edgebenchmark.com" if not os.environ.get("EDGEBENCHMARK_DRY_RUN") else "http://localhost"
+    _MODEL_ENDPOINT = f"{_WEB_SERVER_URL}/api/model"
+    _DEVICE_ENDPOINT = f"{_WEB_SERVER_URL}/api/devices"
+
+    _TFLITE_VERSIONS = [
+        "1.14.0",
+        "1.15.0",
+        "1.15.2",
+        "1.15.3",
+        "1.15.4",
+        "2.0.0",
+        "2.0.1",
+        "2.0.2",
+        "2.0.3",
+        "2.1.0",
+        "2.1.1",
+        "2.1.2",
+        "2.2.0",
+        "2.2.1",
+        "2.3.0",
+        "2.3.1",
+        "2.4.0",
+        "2.4.1",
+    ]
 
 
 class available_benchmarks(Enum):
